@@ -960,7 +960,7 @@ Zarafa.plugins.files.backend.Owncloud.ui.UserGroupPredictorField = Ext.extend(Ex
 			mode: 'remote',
 			minChars: 2,
 			emptyText: _('Type to search'),
-			loadingText: _('Loading...'),
+			loadingText: _('Loading…'),
 			listEmptyText: _('No results'),
 			itemSelector: 'div.ugpredic_search_item',
 			tpl: new Ext.XTemplate(
@@ -1426,7 +1426,7 @@ Zarafa.plugins.files.backend.Owncloud.ui.FilesShareDialogPanel = Ext.extend(Zara
 	 */
 	checkSharedRecord: function () {
 		// init loading mask after the panel was rendered
-		this.loadMask = new Ext.LoadMask(this.getEl(), {msg: _("Loading details...")});
+		this.loadMask = new Ext.LoadMask(this.getEl(), {msg: _("Loading details…")});
 
 		// check if we have a shared record where we should load details
 		if (Ext.isDefined(this.parentRecord)) {
