@@ -98,7 +98,7 @@ Zarafa.plugins.mdm.MDM = Ext.extend(Zarafa.core.Plugin, {
 			value : version
 		};
 	}
-        
+
 });
 
 Zarafa.onReady(function() {
@@ -298,10 +298,11 @@ Zarafa.plugins.mdm.data.MDMResponseHandler = Ext.extend(Zarafa.core.data.Abstrac
 	{
 		if (response.wipe === true) {
 			container.getNotifier().notify('info.mdm', _('Mobile Device Manager'), _('Wiping device'));
+			this.successCallback();
 		} else if (!response.wipe) {
 			container.getNotifier().notify('info.mdm', _('Mobile Device Manager'), _('Password incorrect'));
 		} else {
-			this.processAuthResponse (response, this.failureCallback, 'wipe');
+			this.processAuthResponse(response, this.failureCallback, 'wipe');
 		}
 	},
 
@@ -366,9 +367,6 @@ Zarafa.plugins.mdm.data.MDMDeviceRecordFields = [
 	{name: 'tasksfolder', type: 'string', defaultValue:'0'},
 	{name: 'calendarsfolder', type: 'string', defaultValue:'0'},
 	{name: 'notesfolder', type: 'string', defaultValue:'0'},
-	{name: 'koeversion', type: 'string'},
-	{name: 'koebuild', type: 'string'},
-	{name: 'koebuilddate', type: 'date', dateFormat: 'timestamp'},
 	{name: 'message_class', type: 'string', defaultValue:"IPM.MDM"}
 ];
 
@@ -543,19 +541,40 @@ Zarafa.plugins.mdm.data.ProvisioningStatus = Zarafa.core.Enum.create({
 	'WIPE_PENDING' : 2,
 
 	/**
-	 * Denotes that the Wipe is requested.
+	 * Denotes that the wipe is requested.
 	 * @property
 	 * @type Number
 	 */
 	'WIPE_REQUESTED' : 4,
 
 	/**
-	 * Denotes that the Wipe is executed.
+	 * Denotes that the wipe is executed.
 	 * @property
 	 * @type Number
 	 */
 	'WIPE_EXECUTED' : 8,
 
+	/**
+	 * Denotes that the account only wipe is pending.
+	 * @property
+	 * @type Number
+	 */
+	'WIPE_PENDING_ACCOUNT_ONLY' : 16,
+
+	/**
+	 * Denotes that the account only wipe is requested.
+	 * @property
+	 * @type Number
+	 */
+	'WIPE_REQUESTED_ACCOUNT_ONLY' : 32,
+
+	/**
+	 * Denotes that the account only wipe is executed.
+	 * @property
+	 * @type Number
+	 */
+	'WIPE_EXECUTED_ACCOUNT_ONLY' : 64,
+
 	/**
 	 * Return the display name for the given provisioning Status
 	 * @param {Zarafa.plugins.mdm.js.data.ProvisioningStatus} provisioningStatus The given provisioning status
@@ -574,6 +593,12 @@ Zarafa.plugins.mdm.data.ProvisioningStatus = Zarafa.core.Enum.create({
 				return _('Wipe Requested');
 			case Zarafa.plugins.mdm.data.ProvisioningStatus.WIPE_EXECUTED:
 				return _('Wipe Executed');
+			case Zarafa.plugins.mdm.data.ProvisioningStatus.WIPE_PENDING_ACCOUNT_ONLY:
+				return _('Account Only Wipe Pending');
+			case Zarafa.plugins.mdm.data.ProvisioningStatus.WIPE_REQUESTED_ACCOUNT_ONLY:
+				return _('Account Only Wipe Requested');
+			case Zarafa.plugins.mdm.data.ProvisioningStatus.WIPE_EXECUTED_ACCOUNT_ONLY:
+				return _('Account Only Wipe Executed');
 			default:
 				return _('Not Available');
 		}
@@ -899,8 +924,8 @@ Zarafa.plugins.mdm.settings.MDMSettingsWidget = Ext.extend(Zarafa.settings.ui.Se
 	 */
 	showPasswordMessageBox : function(message, callbackFn, actionType)
 	{
-		var customCfg = this.getCustomItemsAndButtons(actionType);
-		var msgbox = new Zarafa.common.dialogs.CustomMessageBox({
+		var customCfg = this.getCustomItemsAndButtons(actionType, this);
+		new Zarafa.common.dialogs.CustomMessageBox({
 			title:  _('Mobile Device Manager'),
 			msg: message,
 			buttonAlign: 'left',
@@ -924,9 +949,10 @@ Zarafa.plugins.mdm.settings.MDMSettingsWidget = Ext.extend(Zarafa.settings.ui.Se
 	 * based on actiontype.
 	 *
 	 * @param {String} actionType action for which message dialog is needed to be shown.
+	 * @param {Object} scope scope of the action.
 	 * @return {Object} object which contains custom items and custom buttons.
 	 */
-	getCustomItemsAndButtons : function(actionType)
+	getCustomItemsAndButtons : function(actionType, scope)
 	{
 		var customCfg = {};
 		var isAuthenticateAction = actionType === 'authenticate';
@@ -951,6 +977,36 @@ Zarafa.plugins.mdm.settings.MDMSettingsWidget = Ext.extend(Zarafa.settings.ui.Se
 			ref: 'passwordField'
 		}];
 
+		var asVersion = scope?.deviceGrid?.getSelectionModel()?.getSelected()?.get('asversion');
+		if (asVersion !== undefined && parseFloat(asVersion) >= 16.1 && actionType === 'wipe') {
+			customItems.push(
+				{
+					xtype: 'radiogroup',
+					name: 'wipeType',
+					ref: 'wipeType',
+					columns: 1,
+					hideLabel: true,
+					style: 'margin-top: 8px',
+					value: 'accountonly',
+					items: [{
+						xtype: 'radio',
+						name: 'wipeType',
+						inputValue: 'accountonly',
+						boxLabel: _('Wipe only data related to this account'),
+					},{
+						xtype: 'radio',
+						name: 'wipeType',
+						inputValue: 'alldata',
+						boxLabel: _('Wipe all data')
+					}],
+					listeners: {
+						change: scope.onRadioChange,
+						scope: this
+					}
+				}
+			);
+		}
+
 		// For 'authenticate' action username is required in messagebox.
 		if (isAuthenticateAction) {
 			customItems.unshift({
@@ -1033,8 +1089,15 @@ Zarafa.plugins.mdm.settings.MDMSettingsWidget = Ext.extend(Zarafa.settings.ui.Se
 				container.getRequest().singleRequest(
 					'pluginmdmmodule',
 					'wipe',
-					{ 'deviceid' : record.get('entryid'), 'password': inputValues.passwordField },
+					{
+						'deviceid' : record.get('entryid'),
+						'password': inputValues.passwordField,
+						'wipetype': inputValues.wipeType == 'accountonly' ?
+							Zarafa.plugins.mdm.data.ProvisioningStatus.WIPE_PENDING_ACCOUNT_ONLY :
+							Zarafa.plugins.mdm.data.ProvisioningStatus.WIPE_PENDING
+					},
 					new Zarafa.plugins.mdm.data.MDMResponseHandler({
+						successCallback : mdmWidgetScope.refreshGrid,
 						failureCallback : mdmWidgetScope.checkAuthentication,
 						mdmWidgetScope : mdmWidgetScope
 					})
@@ -1126,6 +1189,14 @@ Zarafa.plugins.mdm.settings.MDMSettingsWidget = Ext.extend(Zarafa.settings.ui.Se
 	{
 		this.deviceGrid.getStore().load();
 	},
+	/**
+	 * Function which refreshes the store records from the server after remote
+	 * wipe of a device.
+	 */
+	refreshGrid : function()
+	{
+		this.mdmWidgetScope.deviceGrid.getStore().load();
+	},
 
 	/**
 	 * Function is called if a row in the grid gets double clicked.
@@ -1153,6 +1224,21 @@ Zarafa.plugins.mdm.settings.MDMSettingsWidget = Ext.extend(Zarafa.settings.ui.Se
 	{
 		var record = grid.getStore().getAt(rowIndex);
 		this.wipeBtn.setDisabled(!Ext.isDefined(record.get('wipestatus')));
+	},
+
+	/**
+	 * Event handler which is fired when a {@link Ext.form.Radio} in the
+	 * {@link Ext.form.RadioGroup} has been changed. This will set the value
+	 * selected by user in settingsModel.
+	 * @param {Ext.form.RadioGroup} group The radio group which fired the event
+	 * @param {Ext.form.Radio} radio The radio which was enabled
+	 * @private
+	 */
+	onRadioChange: function(group, radio)
+	{
+		if (this.model && (this.model.get(group.name) !== radio.inputValue)) {
+			this.model.set(group.name, radio.inputValue);
+		}
 	}
 });
 
@@ -1210,7 +1296,6 @@ Zarafa.plugins.mdm.dialogs.MDMDeviceContentPanel = Ext.extend(Zarafa.core.ui.Rec
 	constructor: function (config)
 	{
 		config = config || {};
-		var isKOE = config.record && config.record.get('koeversion') ? true : false;
 		Ext.applyIf(config, {
 			xtype: 'mdmplugin.devicecontentpanel',
 			modal: true,
@@ -1224,12 +1309,11 @@ Zarafa.plugins.mdm.dialogs.MDMDeviceContentPanel = Ext.extend(Zarafa.core.ui.Rec
 			stateful: false,
 			showInfoMask : false,
 			showLoadMask: false,
-			width: isKOE ? 440 : 405,
-			height: isKOE ? 450 : 420,
+			width: 405,
+			height: 420,
 			items: [{
 				xtype: 'mdmplugin.mdmdevicepanel',
 				record: config.record,
-				isKoe: isKOE,
 				buttons: [{
 					text: _('Ok'),
 					handler: this.onOk,
@@ -1262,11 +1346,6 @@ Ext.reg('mdmplugin.devicecontentpanel', Zarafa.plugins.mdm.dialogs.MDMDeviceCont
  */
 Zarafa.plugins.mdm.dialogs.MDMDeviceGeneralTab = Ext.extend(Ext.form.FormPanel, {
 
-	/**
-	 * @cfg {Boolean} isKoe True if device has Outlook Extension information.
-	 */
-	isKoe: false,
-
 	/**
 	 * @constructor
 	 * @param {Object} config Configuration object
@@ -1323,7 +1402,6 @@ Zarafa.plugins.mdm.dialogs.MDMDeviceGeneralTab = Ext.extend(Ext.form.FormPanel,
 				value: String.format(_('{0}'), new Date(config.record.get('lastupdatetime')).format(_('d F Y, H:i')))
 			}, {
 				fieldLabel: _('Status'),
-				hidden: config.isKoe,
 				listeners: {
 					afterrender: this.onAfterRenderStatus,
 					scope: this
@@ -1377,7 +1455,7 @@ Zarafa.plugins.mdm.dialogs.MDMDeviceGeneralTab = Ext.extend(Ext.form.FormPanel,
 					fieldLabel: _('Tasks'),
 					name: 'tasksfolder'
 				},
-                    // this.createSharedFolderInfoPanel()
+				// this.createSharedFolderInfoPanel()
 				]
 			}]
 		};
@@ -1471,11 +1549,6 @@ Ext.namespace('Zarafa.plugins.mdm.dialogs');
  */
 Zarafa.plugins.mdm.dialogs.MDMDevicePanel = Ext.extend(Ext.Panel, {
 
-	/**
-	 * @cfg {Boolean} isKoe True if device has Outlook Extension information.
-	 */
-	isKoe : false,
-
 	/**
 	 * @constructor
 	 * @param {Object} config configuration object.
@@ -1497,12 +1570,10 @@ Zarafa.plugins.mdm.dialogs.MDMDevicePanel = Ext.extend(Ext.Panel, {
 					xtype: 'mdmplugin.mdmdevicegeneraltab',
 					record: config.record,
 					title: _('General'),
-					isKoe : config.isKoe
 				}, {
 					xtype: 'mdmplugin.mdmdevicedetailstab',
 					record: config.record,
 					title: _('Details'),
-					isKoe : config.isKoe
 				}]
 			}]
 		});
@@ -1523,11 +1594,6 @@ Ext.namespace('Zarafa.plugins.mdm.dialogs');
  */
 Zarafa.plugins.mdm.dialogs.MDMDeviceDetailsTab = Ext.extend(Ext.form.FormPanel, {
 
-	/**
-	 * @cfg {Boolean} isKoe True if device has Outlook Extension information.
-	 */
-	isKoe : false,
-
 	/**
 	 * @constructor
 	 * @param {Object} config
@@ -1548,24 +1614,19 @@ Zarafa.plugins.mdm.dialogs.MDMDeviceDetailsTab = Ext.extend(Ext.form.FormPanel,
 			},
 			plugins : ['zarafa.recordcomponentupdaterplugin'],
 			items: [
-				this.createDeviceInfoPanel(config.isKoe),
-				this.createVersionInfoPanel(config.isKoe)
+				this.createDeviceInfoPanel(),
+				this.createVersionInfoPanel()
 			]
 		});
 
-		// KOE information
-		if (config.isKoe) {
-			config.items.push(this.createKOEInfoPanel(config.record));
-		}
 		Zarafa.plugins.mdm.dialogs.MDMDeviceDetailsTab.superclass.constructor.call(this, config);
 	},
 	/**
 	 * Function which is use to create device information panel
-	 * @param {Boolean} isKoe True if device has Outlook Extension information, false otherwise.
 	 * @return {Object} Configuration object for the panel which shows device properties
 	 * @private
 	 */
-	createDeviceInfoPanel: function (isKoe)
+	createDeviceInfoPanel: function ()
 	{
 		return {
 			cls : 'mdm-device-panel',
@@ -1583,7 +1644,6 @@ Zarafa.plugins.mdm.dialogs.MDMDeviceDetailsTab = Ext.extend(Ext.form.FormPanel,
 				name: 'devicetype'
 			}, {
 				fieldLabel: _('Operating System'),
-				hidden: isKoe,
 				name: 'deviceos'
 			}, {
 				fieldLabel: _('ID'),
@@ -1597,11 +1657,10 @@ Zarafa.plugins.mdm.dialogs.MDMDeviceDetailsTab = Ext.extend(Ext.form.FormPanel,
 
 	/**
 	 * Function which is use to create version information panel.
-	 * @param {Boolean} isKoe True if device has Outlook Extension information, false otherwise.
 	 * @return {Object} Configuration object for the panel which shows versions properties
 	 * @private
 	 */
-	createVersionInfoPanel: function (isKoe)
+	createVersionInfoPanel: function ()
 	{
 		return {
 			defaultType: 'displayfield',
@@ -1628,39 +1687,6 @@ Zarafa.plugins.mdm.dialogs.MDMDeviceDetailsTab = Ext.extend(Ext.form.FormPanel,
 		};
 	},
 
-	/**
-	 * Function which is use to create Outlook Extension panel
-	 * @param {Zarafa.plugins.mdm.data.MDMDeviceRecord} record The device record.s
-	 * @return {Object} Configuration object for the panel which shows Outlook Extension properties
-	 * @private
-	 */
-	createKOEInfoPanel: function (record)
-	{
-		return {
-			cls : 'mdm-device-panel mdm-field-sep',
-			defaults: {
-				disabled: true
-			},
-			defaultType: 'displayfield',
-			items: [{
-				cls: 'mdm-display-name',
-				value: _('Outlook Extension'),
-				htmlEncode: true,
-				hideLabel: true,
-				disabled: false
-			}, {
-				fieldLabel: _('Version'),
-				name: "koeversion"
-			}, {
-				fieldLabel: _('Build'),
-				name: "koebuild"
-			}, {
-				fieldLabel: _('Last updated'),
-				value: String.format('{0}', new Date(record.get('koebuilddate')).format(_('d F Y, H:i')))
-			}]
-		};
-	},
-
 	/**
 	 * Updates the panel by loading data from the record.
 	 *
