@@ -12,6 +12,10 @@ class PluginMDMModule extends Module {
 	public const FOLDERTYPE = 2;
 	public const FOLDERBACKENDID = 5;
 
+	private $stateFolder;
+	private $deviceStates;
+	private $devices;
+
 	/**
 	 * Constructor.
 	 *
@@ -69,7 +73,7 @@ class PluginMDMModule extends Module {
 	 *
 	 * @param string $deviceid of phone which has to be resynced
 	 *
-	 * @return json $response object contains the response of the soap request from grommunio-sync
+	 * @return bool $response true if removing states succeeded or false on failure
 	 */
 	public function resyncDevice($deviceid) {
 		$deviceStateFolder = $this->deviceStates[$deviceid];
@@ -106,10 +110,11 @@ class PluginMDMModule extends Module {
 	 *
 	 * @param string $deviceid of phone which has to be wiped
 	 * @param string $password user password
+	 * @param int    $wipeType remove account only or all data
 	 *
-	 * @return json $response object contains the response of the soap request from grommunio-sync
+	 * @return bool true if the request was successful, false otherwise
 	 */
-	public function wipeDevice($deviceid, $password) {
+	public function wipeDevice($deviceid, $password, $wipeType = SYNC_PROVISION_RWSTATUS_PENDING) {
 		$opts = ['http' => [
 			'method' => 'POST',
 			'header' => 'Content-Type: application/json',
@@ -118,24 +123,25 @@ class PluginMDMModule extends Module {
 				[
 					'password' => $password,
 					'remoteIP' => '[::1]',
-					'status' => SYNC_PROVISION_RWSTATUS_PENDING,
+					'status' => $wipeType,
 					'time' => time(),
 				]
 			),
 		],
 		];
 		$ret = file_get_contents(PLUGIN_MDM_ADMIN_API_WIPE_ENDPOINT . $GLOBALS["mapisession"]->getUserName() . "?devices=" . $deviceid, false, stream_context_create($opts));
+		$ret = json_decode($ret, true);
 
-		return $ret;
+		return strncasecmp('success', $ret['message'], 7) === 0;
 	}
 
 	/**
 	 * Function which triggers removal of a device.
 	 *
-	 * @param string $deviceid of phone which has to be wiped
+	 * @param string $deviceid of phone which has to be removed
 	 * @param string $password user password
 	 *
-	 * @return json $response object contains the response of the soap request from grommunio-sync
+	 * @return bool|string $response object contains the response of the soap request from grommunio-sync or false on failure
 	 */
 	public function removeDevice($deviceid, $password) {
 		// TODO remove the device from device / user list
@@ -205,10 +211,9 @@ class PluginMDMModule extends Module {
 				try {
 					switch ($actionType) {
 						case 'wipe':
-							$this->wipeDevice($actionData['deviceid'], $actionData['password']);
 							$this->addActionData('wipe', [
 								'type' => 3,
-								'wipe' => $this->wipeDevice($actionData['deviceid'], $actionData['password']),
+								'wipe' => $this->wipeDevice($actionData['deviceid'], $actionData['password'], $actionData['wipetype']),
 							]);
 							$GLOBALS['bus']->addData($this->getResponseData());
 							break;
@@ -252,8 +257,7 @@ class PluginMDMModule extends Module {
 							break;
 
 						case 'save':
-							$this->saveDevice($actionData)
-							;
+							$this->saveDevice($actionData);
 							$device = $this->getDeviceDetails($actionData["entryid"]);
 							$item = ["item" => $device];
 							$this->addActionData('update', $item);
