@@ -20,7 +20,7 @@
 		protected $tzdef;
 
 		/**
-		 * @var bool|array client timezone definition array
+		 * @var array|bool client timezone definition array
 		 */
 		protected $tzdefObj;
 
@@ -29,21 +29,6 @@
 		 */
 		protected $tzEffRuleIdx;
 
-		/**
-		 * @var array list of days of week
-		 */
-		private $daysOfWeek;
-
-		/**
-		 * @var array list of months names starting at 1
-		 */
-		private $monthNames;
-
-		/**
-		 * @var array list of relative days of week:
-		 */
-		private $relDaysOfWeek;
-
 		/**
 		 * Constructor.
 		 *
@@ -59,16 +44,6 @@
 			$this->enddate = false;
 			$this->tzdef = false;
 			$this->tzdefObj = false;
-			$this->daysOfWeek = ["Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"];
-			$this->monthNames = [1 => "January", "February", "March", "April", "May", "June",
-				"July", "August", "September", "October", "November", "December", ];
-			$this->relDaysOfWeek = [
-				1 => 'first',
-				2 => 'second',
-				3 => 'third',
-				4 => 'fourth',
-				5 => 'last',
-			];
 		}
 
 		/**
@@ -153,7 +128,8 @@
 				if (!empty($action["timezone_iana"])) {
 					try {
 						$this->tzdef = mapi_ianatz_to_tzdef($action['timezone_iana']);
-					} catch (Exception $e) {
+					}
+					catch (Exception $e) {
 					}
 				}
 
@@ -282,20 +258,12 @@
 		 * Function to return all Calendar items in a given timeframe. This
 		 * function also takes recurring items into account.
 		 *
-		 * @param object $store    message store
-		 * @param object $calendar folder
-		 * @param date   $start    startdate of the interval
-		 * @param date   $end      enddate of the interval
-		 * @param mixed  $entryid
+		 * @param object $store   message store
+		 * @param mixed  $entryid entryid of the folder
+		 * @param mixed  $start   startdate of the interval
+		 * @param mixed  $end     enddate of the interval
 		 */
 		public function getCalendarItems($store, $entryid, $start, $end) {
-			// Create mapping for restriction used properties which should not be send to the client.
-			$properties = [
-				"clipstart" => "PT_SYSTIME:PSETID_Appointment:" . PidLidClipStart,
-				"clipend" => "PT_SYSTIME:PSETID_Appointment:" . PidLidClipEnd,
-			];
-			$properties = getPropIdsFromStrings($store, $properties);
-
 			$restriction =
 				// OR
 				//  - Either we want all appointments which fall within the given range
@@ -359,6 +327,9 @@
 						],
 						// OR
 						// (item[isRecurring] == true)
+						// Add one day to the start and the end of the periods to avoid
+						// timezone offset related differences between start/clipstart
+						// and end/clipend.
 						[RES_AND,
 							[
 								[RES_PROPERTY,
@@ -371,14 +342,14 @@
 									[
 										[RES_PROPERTY,
 											[RELOP => RELOP_GT,
-												ULPROPTAG => $properties["clipend"],
-												VALUE => $start,
+												ULPROPTAG => $this->properties["enddate_recurring"],
+												VALUE => (int) $start - 86400,
 											],
 										],
 										[RES_PROPERTY,
 											[RELOP => RELOP_LT,
-												ULPROPTAG => $properties["clipstart"],
-												VALUE => $end,
+												ULPROPTAG => $this->properties["startdate_recurring"],
+												VALUE => (int) $end + 86400,
 											],
 										],
 									],
@@ -388,11 +359,21 @@
 					],
 				]; // global OR
 
-			$folder = mapi_msgstore_openentry($store, $entryid);
-			$table = mapi_folder_getcontentstable($folder, MAPI_DEFERRED_ERRORS);
-			$calendaritems = mapi_table_queryallrows($table, $this->properties, $restriction);
+			try {
+				$folder = mapi_msgstore_openentry($store, $entryid);
+				$table = mapi_folder_getcontentstable($folder, MAPI_DEFERRED_ERRORS);
+				$calendaritems = mapi_table_queryallrows($table, $this->properties, $restriction);
 
-			return $this->processItems($calendaritems, $store, $entryid, $start, $end);
+				return $this->processItems($calendaritems, $store, $entryid, $start, $end);
+			}
+			catch (Exception $e) {
+				// MAPI_E_NOT_FOUND means missing permissions, try to get items via freebusy
+				if ($e->getCode() == MAPI_E_NOT_FOUND) {
+					return $this->getFreebusyItems($store, $entryid, $start, $end);
+				}
+			}
+
+			return [];
 		}
 
 		/**
@@ -400,10 +381,9 @@
 		 *
 		 * @param array  $calendaritems array of appointments retrieved from the mapi tablwe
 		 * @param object $store         message store
-		 * @param object $calendar      folder
-		 * @param date   $start         startdate of the interval
-		 * @param date   $end           enddate of the interval
 		 * @param mixed  $entryid
+		 * @param mixed  $start         startdate of the interval
+		 * @param mixed  $end           enddate of the interval
 		 *
 		 * @return array $items processed items
 		 */
@@ -415,9 +395,6 @@
 			foreach ($calendaritems as $calendaritem) {
 				$item = null;
 				// Fix for all-day events which have a different timezone than the user's browser
-				if ($calendaritem[$this->properties["alldayevent"]] == true && $this->tzdef !== false) {
-					$this->processAllDayItem($store, $calendaritem, $openedMessages);
-				}
 				if (isset($calendaritem[$this->properties["recurring"]]) && $calendaritem[$this->properties["recurring"]]) {
 					$recurrence = new Recurrence($store, $calendaritem, $proptags);
 					$recuritems = $recurrence->getItems($start, $end);
@@ -476,6 +453,9 @@
 							if (empty($item["props"]["commonend"]) && isset($item["props"]["duedate"])) {
 								$item["props"]["commonend"] = $item["props"]["duedate"];
 							}
+							if (isset($item["props"]["alldayevent"]) && $item["props"]["alldayevent"]) {
+								$this->processAllDayItem($store, $item, $openedMessages);
+							}
 							array_push($items, $item);
 						}
 					}
@@ -493,6 +473,9 @@
 						if (empty($item["props"]["commonend"]) && isset($item["props"]["duedate"])) {
 							$item["props"]["commonend"] = $item["props"]["duedate"];
 						}
+						if (isset($item["props"]["alldayevent"]) && $item["props"]["alldayevent"]) {
+							$this->processAllDayItem($store, $item, $openedMessages);
+						}
 						array_push($items, $item);
 					}
 				}
@@ -549,150 +532,132 @@
 			return ($start_a < $start_b) ? -1 : 1;
 		}
 
-		/**
-		 * Formats time string for DateTime object, e.g.
-		 * last Sunday of March 2022 02:00
-		 */
-		private function formatDateTimeString($relDayofWeek, $dayOfWeek, $month, $year, $hour, $minute) {
-			return sprintf("%s %s of %s %04d %02d:%02d", $relDayofWeek, $dayOfWeek, $month, $year, $hour, $minute);
-		}
-
 		/**
 		 * Processes an all-day item and calculates the correct starttime if necessary.
-		 * 
+		 *
 		 * @param object $store
 		 * @param array  $calendaritem
 		 * @param array  $openedMessages
 		 */
 		private function processAllDayItem($store, &$calendaritem, &$openedMessages) {
-			if (!isset($calendaritem[$this->properties["tzdefstart"]])) {
+			if (!isset($calendaritem['props']['tzdefstart'])) {
 				return;
 			}
-			$appStartDate = getdate($calendaritem[$this->properties["startdate"]]);
+			$tzdefstart = hex2bin($calendaritem['props']['tzdefstart']);
 
 			// queryrows only returns 510 chars max, so if tzdef is longer than that
 			// it was probably silently truncated. In such case we need to open
 			// the message and read the prop value as stream.
-			if (strlen($calendaritem[$this->properties["tzdefstart"]]) > 500) {
-				$message = mapi_msgstore_openentry($store, $calendaritem[$this->properties["entryid"]]);
-				$calendaritem[$this->properties["tzdefstart"]] = streamProperty($message, $this->properties["tzdefstart"]);
-				$openedMessages[bin2hex($calendaritem[$this->properties["entryid"]])] = $message;
+			if (strlen($calendaritem['props']['tzdefstart']) > 500) {
+				if (!isset($openedMessages[$calendaritem['entryid']])) {
+					// Open the message and add it to the openedMessages property
+					$openedMessages[$calendaritem['entryid']] = mapi_msgstore_openentry($store, hex2bin($calendaritem['entryid']));
+				}
+				$tzdefstart = streamProperty($openedMessages[$calendaritem['entryid']], $this->properties['tzdefstart']);
 			}
 
 			// Compare the timezone definitions of the client and the appointment.
 			// Further processing is only required if they don't match.
-			if (!$GLOBALS["entryid"]->compareEntryIds($this->tzdef, $calendaritem[$this->properties["tzdefstart"]])) {
+			if (!$GLOBALS['entryid']->compareEntryIds($this->tzdef, $tzdefstart)) {
 				if ($this->tzdefObj === false) {
-					$this->tzdefObj = $GLOBALS["entryid"]->createTimezoneDefinitionObject($this->tzdef);
-					foreach ($this->tzdefObj['rules'] as $idx => $tzDefRule) {
-						if ($tzDefRule['tzruleflags'] & TZRULE_FLAG_EFFECTIVE_TZREG) {
-							$this->tzEffRuleIdx = $idx;
-							break;
-						}
-					}
+					$this->tzdefObj = $GLOBALS['entryid']->createTimezoneDefinitionObject($this->tzdef);
 				}
-				$appTzDefStart = $GLOBALS["entryid"]->createTimezoneDefinitionObject($calendaritem[$this->properties["tzdefstart"]]);
+				$this->tzEffRuleIdx = getEffectiveTzreg($this->tzdefObj['rules']);
 
+				$appTzDefStart = $GLOBALS['entryid']->createTimezoneDefinitionObject($tzdefstart);
 				// Find TZRULE_FLAG_EFFECTIVE_TZREG rule for the appointment's timezone
-				foreach ($appTzDefStart['rules'] as $idx => $tzDefRule) {
-					if ($tzDefRule['tzruleflags'] & TZRULE_FLAG_EFFECTIVE_TZREG) {
-						$appTzEffRuleIdx = $idx;
-						break;
-					}
-				}
-				if (isset($this->tzEffRuleIdx, $appTzEffRuleIdx)) {
+				$appTzEffRuleIdx = getEffectiveTzreg($appTzDefStart['rules']);
+
+				if (!is_null($this->tzEffRuleIdx) && !is_null($appTzEffRuleIdx)) {
 					// first apply the bias of the appointment timezone and the bias of the browser
-					$localStart = $calendaritem[$this->properties["startdate"]] - $appTzDefStart['rules'][$appTzEffRuleIdx]['bias'] * 60 + $this->tzdefObj['rules'][$this->tzEffRuleIdx]['bias'] * 60;
-
-					// Apply dstbias if necessary
-					// 1. Check if the appointment timezone defines std and dst times
-					// 2. Get the std and dst start in UTC
-					// 3. Check if the appointment is in dst:
-					// 	- dst start > std start and not (std start < app time < dst start)
-					// 	- dst start < std start and std start > app time > dst start
-					if (array_sum($appTzDefStart['rules'][$appTzEffRuleIdx]['stStandardDate']) != 0 &&
-								array_sum($appTzDefStart['rules'][$appTzEffRuleIdx]['stDaylightDate']) != 0) {
-						$appTzStd = $appTzDefStart['rules'][$appTzEffRuleIdx]['stStandardDate'];
-						$appTzDst = $appTzDefStart['rules'][$appTzEffRuleIdx]['stDaylightDate'];
-
-						$f = $this->formatDateTimeString(
-							$this->relDaysOfWeek[$appTzStd['day']],
-							$this->daysOfWeek[$appTzStd['dayofweek']],
-							$this->monthNames[$appTzStd['month']],
-							$appStartDate['year'],
-							$appTzStd['hour'],
-							$appTzStd['minute'],
-						);
-
-						$dtStd = new DateTime($f, new DateTimeZone("UTC"));
-
-						$f = $this->formatDateTimeString(
-							$this->relDaysOfWeek[$appTzDst['day']],
-							$this->daysOfWeek[$appTzDst['dayofweek']],
-							$this->monthNames[$appTzDst['month']],
-							$appStartDate['year'],
-							$appTzDst['hour'],
-							$appTzDst['minute'],
-						);
-
-						$dtDst = new DateTime($f, new DateTimeZone("UTC"));
-
-						$appTzStdStart = $dtStd->getTimestamp();
-						$appTzDstStart = $dtDst->getTimestamp();
-
-						if ((($appTzDstStart > $appTzStdStart) &&
-							!($calendaritem[$this->properties["startdate"]] > $appTzStdStart &&
-							$calendaritem[$this->properties["startdate"]] < $appTzDstStart)) ||
-							(($appTzDstStart < $appTzStdStart) &&
-							($calendaritem[$this->properties["startdate"]] < $appTzStdStart &&
-							$calendaritem[$this->properties["startdate"]] > $appTzDstStart))
-						) {
-							$localStart = $localStart - $appTzDefStart['rules'][$appTzEffRuleIdx]['dstbias'] * 60;
-						}
+					$localStart = $calendaritem['props']['startdate'] - $appTzDefStart['rules'][$appTzEffRuleIdx]['bias'] * 60 + $this->tzdefObj['rules'][$this->tzEffRuleIdx]['bias'] * 60;
+					if (isDst($appTzDefStart['rules'][$appTzEffRuleIdx], $calendaritem['props']['startdate'])) {
+						$localStart -= $appTzDefStart['rules'][$appTzEffRuleIdx]['dstbias'] * 60;
 					}
-					if (array_sum($this->tzdefObj['rules'][$this->tzEffRuleIdx]['stStandardDate']) != 0 &&
-								array_sum($this->tzdefObj['rules'][$this->tzEffRuleIdx]['stDaylightDate']) != 0) {
-						$tzStd = $this->tzdefObj['rules'][$this->tzEffRuleIdx]['stStandardDate'];
-						$tzDst = $this->tzdefObj['rules'][$this->tzEffRuleIdx]['stDaylightDate'];
-
-						$f = $this->formatDateTimeString(
-							$this->relDaysOfWeek[$tzStd['day']],
-							$this->daysOfWeek[$tzStd['dayofweek']],
-							$this->monthNames[$tzStd['month']],
-							$appStartDate['year'],
-							$tzStd['hour'],
-							$tzStd['minute'],
-						);
-						$dtStd = new DateTime($f, new DateTimeZone("UTC"));
-
-						$f = $this->formatDateTimeString(
-							$this->relDaysOfWeek[$tzDst['day']],
-							$this->daysOfWeek[$tzDst['dayofweek']],
-							$this->monthNames[$tzDst['month']],
-							$appStartDate['year'],
-							$tzDst['hour'],
-							$tzDst['minute'],
-						);
-						$dtDst = new DateTime($f, new DateTimeZone("UTC"));
-
-						$tzStdStart = $dtStd->getTimestamp();
-						$tzDstStart = $dtDst->getTimestamp();
-
-						if (
-							(($tzDstStart > $tzStdStart) &&
-							!($calendaritem[$this->properties["startdate"]] > $tzStdStart &&
-							$calendaritem[$this->properties["startdate"]] < $tzDstStart)) ||
-							(($tzDstStart < $tzStdStart) &&
-							($calendaritem[$this->properties["startdate"]] < $tzStdStart &&
-							$calendaritem[$this->properties["startdate"]] > $tzDstStart))
-						) {
-							$localStart -= $this->tzdefObj['rules'][$this->tzEffRuleIdx]['dstbias'] * 60;
-						}
+					if (isDst($this->tzdefObj['rules'][$this->tzEffRuleIdx], $calendaritem['props']['startdate'])) {
+						$localStart += $this->tzdefObj['rules'][$this->tzEffRuleIdx]['dstbias'] * 60;
 					}
-					$duration = $calendaritem[$this->properties["duedate"]] - $calendaritem[$this->properties["startdate"]];
-					$calendaritem[$this->properties["startdate"]] = $localStart;
-					$calendaritem[$this->properties["duedate"]] = $localStart + $duration;
+					$duration = $calendaritem['props']['duedate'] - $calendaritem['props']['startdate'];
+					$calendaritem['props']['startdate'] = $calendaritem['props']['commonstart'] = $localStart;
+					$calendaritem['props']['duedate'] = $calendaritem['props']['commonend'] = $localStart + $duration;
 				}
 			}
 		}
+
+		/**
+		 * Gets items using freebusy entry point.
+		 *
+		 * @param object $store         message store
+		 * @param mixed  $folderEntryid entryid of the folder
+		 * @param mixed  $start         startdate of the interval
+		 * @param mixed  $end           enddate of the interval
+		 */
+		public function getFreebusyItems($store, $folderEntryid, $start, $end) {
+			$items = [];
+			$storeProps = mapi_getprops($store, [PR_ENTRYID, PR_MAILBOX_OWNER_ENTRYID]);
+			$folderEntryid = bin2hex($folderEntryid);
+			$storeEntryid = bin2hex($storeProps[PR_ENTRYID]);
+			// if start was not set, get items one month back
+			if ($start === false) {
+				$start = time() - 2592000;
+			}
+			// if end was not set, get items 3 months ahead
+			if ($end === false) {
+				$end = time() + 7776000;
+			}
+			$fbdata = mapi_getuserfreebusy($GLOBALS['mapisession']->getSession(), $storeProps[PR_MAILBOX_OWNER_ENTRYID], $start, $end);
+			if (!empty($fbdata['fbevents'])) {
+				foreach ($fbdata['fbevents'] as $fbEvent) {
+					// check if the event is in start - end range
+					if ($fbEvent['end'] < $start || $fbEvent['start'] > $end) {
+						continue;
+					}
+					$items[] = [
+						// entryid is required, generate a fake one if a real is not available
+						'entryid' => isset($fbEvent['id']) ? bin2hex($fbEvent['id']) : bin2hex(random_bytes(16)),
+						'parent_entryid' => $folderEntryid,
+						'store_entryid' => $storeEntryid,
+						'props' => [
+							'access' => 0,
+							'subject' => $fbEvent['subject'] ?? _('Busy'),
+							'normalized_subject' => $fbEvent['subject'] ?? _('Busy'),
+							'location' => $fbEvent['location'] ?? '',
+							'startdate' => $fbEvent['start'],
+							'duedate' => $fbEvent['end'],
+							'commonstart' => $fbEvent['start'],
+							'commonend' => $fbEvent['end'],
+							'message_class' => 'IPM.Appointment',
+							'object_type' => MAPI_MESSAGE,
+							'icon_index' => 1024,
+							'display_to' => '',
+							'display_cc' => '',
+							'display_bcc' => '',
+							'importance' => 1,
+							'sensitivity' => 0,
+							'message_size' => 0,
+							'hasattach' => false,
+							'sent_representing_entryid' => '',
+							'sent_representing_name' => '',
+							'sent_representing_address_type' => '',
+							'sent_representing_email_address' => '',
+							'sent_representing_search_key' => '',
+							'sender_email_address' => '',
+							'sender_name' => '',
+							'sender_address_type' => '',
+							'sender_entryid' => '',
+							'sender_search_key' => '',
+							'recurring' => false,
+							'recurring_data' => '',
+							'recurring_pattern' => '',
+							'label' => 0,
+							'meeting' => $fbEvent['meeting'],
+							'reminder' => 0,
+							'reminder_minutes' => 0,
+						]
+					];
+				}
+			}
+
+			return $items;
+		}
 	}
